api.currentuser.v1.test_helpers.prefs package — Argus-Toolbelt 1.0 documentation

# api.currentuser.v1.test_helpers.prefs package

## Submodules

## api.currentuser.v1.test_helpers.prefs.delete_properties module

`api.currentuser.v1.test_helpers.prefs.delete_properties.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 403

`api.currentuser.v1.test_helpers.prefs.delete_properties.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 404

`api.currentuser.v1.test_helpers.prefs.delete_properties.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 200

`api.currentuser.v1.test_helpers.prefs.delete_properties.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 401

## api.currentuser.v1.test_helpers.prefs.delete_property module

`api.currentuser.v1.test_helpers.prefs.delete_property.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs/w+, respond with HTTP 403

`api.currentuser.v1.test_helpers.prefs.delete_property.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs/w+, respond with HTTP 404

`api.currentuser.v1.test_helpers.prefs.delete_property.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs/w+, respond with HTTP 200

`api.currentuser.v1.test_helpers.prefs.delete_property.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs/w+, respond with HTTP 401

## api.currentuser.v1.test_helpers.prefs.get_property module

`api.currentuser.v1.test_helpers.prefs.get_property.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs/w+, respond with HTTP 403

`api.currentuser.v1.test_helpers.prefs.get_property.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs/w+, respond with HTTP 404

`api.currentuser.v1.test_helpers.prefs.get_property.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs/w+, respond with HTTP 200

`api.currentuser.v1.test_helpers.prefs.get_property.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs/w+, respond with HTTP 401

## api.currentuser.v1.test_helpers.prefs.list_properties module

`api.currentuser.v1.test_helpers.prefs.list_properties.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 403

`api.currentuser.v1.test_helpers.prefs.list_properties.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 404

`api.currentuser.v1.test_helpers.prefs.list_properties.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 200

`api.currentuser.v1.test_helpers.prefs.list_properties.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 401

## api.currentuser.v1.test_helpers.prefs.set_properties module

`api.currentuser.v1.test_helpers.prefs.set_properties.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 403

`api.currentuser.v1.test_helpers.prefs.set_properties.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 404

`api.currentuser.v1.test_helpers.prefs.set_properties.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 200

`api.currentuser.v1.test_helpers.prefs.set_properties.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/prefs, respond with HTTP 401

## Module contents